@@ -60,8 +60,8 @@ def calculateCoilmapsWalsh(img, smoothing=5, niter=3, device=None):
         # At each point in the image, find the dominant eigenvector
         # and corresponding eigenvalue of the signal covariance
         # matrix using the power method
-        rho = torch.zeros((nx, ny, nz))
-        csm = torch.zeros((ncoils, nx, ny, nz),dtype=torch.complex64)
+        rho = torch.zeros((nx, ny, nz)).to(device)
+        csm = torch.zeros((ncoils, nx, ny, nz),dtype=torch.complex64).to(device)
         for z in range(nz):
             Rs_dev = Rs[:,:,:,:,z].to(device) 
             v_dev = torch.sum(Rs_dev,axis=0).to(device)
@@ -71,8 +71,8 @@ def calculateCoilmapsWalsh(img, smoothing=5, niter=3, device=None):
                 v_dev = torch.sum(Rs_dev * v_dev, axis=1)
                 lam_dev = torch.linalg.norm(v_dev, axis=0)
                 v_dev = v_dev / lam_dev
-            rho[:,:,z] = lam_dev.cpu()
-            csm[:,:,:,z] = v_dev.cpu()
+            rho[:,:,z] = lam_dev
+            csm[:,:,:,z] = v_dev
             del Rs_dev, v_dev, lam_dev
         return (csm, rho)
     
